@@ -42,11 +42,13 @@
 
 #include <QtWebEngineWidgets/qtwebenginewidgetsglobal.h>
 
-#include <QtCore/qscopedpointer.h>
+#include <QtCore/qsharedpointer.h>
 #include <QtCore/qurl.h>
+#include <QtNetwork/QSslCertificate>
 
 QT_BEGIN_NAMESPACE
 
+class CertificateErrorController;
 class QWebEngineCertificateErrorPrivate;
 
 class QWEBENGINEWIDGETS_EXPORT QWebEngineCertificateError {
@@ -70,6 +72,8 @@ public:
         CertificateWeakKey = -211,
         CertificateNameConstraintViolation = -212,
         CertificateValidityTooLong = -213,
+        CertificateTransparencyRequired = -214,
+        CertificateKnownInterceptionBlocked = -217,
     };
 
     Error error() const;
@@ -77,10 +81,22 @@ public:
     bool isOverridable() const;
     QString errorDescription() const;
 
+    QWebEngineCertificateError(const QWebEngineCertificateError &other);
+    QWebEngineCertificateError& operator=(const QWebEngineCertificateError &other);
+
+    void defer();
+    bool deferred() const;
+
+    void rejectCertificate();
+    void ignoreCertificateError();
+    bool answered() const;
+
+    QList<QSslCertificate> certificateChain() const;
+
 private:
-    Q_DISABLE_COPY(QWebEngineCertificateError)
-    Q_DECLARE_PRIVATE(QWebEngineCertificateError)
-    QScopedPointer<QWebEngineCertificateErrorPrivate> d_ptr;
+    friend class QWebEnginePagePrivate;
+    QWebEngineCertificateError(const QSharedPointer<CertificateErrorController> &controller);
+    QExplicitlySharedDataPointer<QWebEngineCertificateErrorPrivate> d;
 };
 
 QT_END_NAMESPACE
